@@ -125,6 +125,9 @@ class System(object):
 			"public_id" : self.public_id,
 			"private_id" : self.private_id,
 
+			# XXX just for beta
+			"secret_id" : self._unique_id,
+
 			# Actual profile data
 			"profile" : p,
 		}
@@ -242,7 +245,7 @@ class System(object):
 	@property
 	def vendor(self):
 		ret = None
-		for file in ("chassis_vendor", "board_vendor", "sys_vendor",):
+		for file in ("sys_vendor", "board_vendor", "chassis_vendor",):
 			ret = read_from_file(os.path.join(SYS_CLASS_DMI, file))
 			if ret:
 				break
@@ -252,7 +255,7 @@ class System(object):
 	@property
 	def model(self):
 		ret = None
-		for file in ("chassis_model", "board_model", "product_name",):
+		for file in ("product_name", "board_model", "chassis_model",):
 			ret = read_from_file(os.path.join(SYS_CLASS_DMI, file))
 			if ret:
 				break
